#line 2 "pgc.c"

#line 4 "pgc.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 103
#define YY_END_OF_BUFFER 104
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[446] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   10,   10,    0,    0,    0,    0,    0,    0,
        9,    9,    0,    0,    0,    0,    0,    0,    0,    0,
      104,  103,  103,  103,  103,   80,   58,   58,   80,   28,
       80,   43,   52,   80,   16,   56,   57,   51,   54,   50,
       55,   80,   53,   35,   35,   49,   80,   63,   80,   48,
       48,   61,   62,   59,   80,   60,   41,    1,    1,   33,
       23,   31,   32,   16,   32,   32,   32,   32,   35,   32,
       40,   40,   40,   40,  103,  103,  103,  103,  103,  103,
       99,   99,   99,   99,   99,   98,   97,   10,    8,    5,

        5,    6,    6,   27,   24,   29,   25,   29,    9,   14,
       19,   17,  103,  103,   95,   58,   58,   95,   95,   37,
        2,   37,    0,    0,    0,   72,    0,    0,    0,    0,
        0,    0,   77,   68,   75,   69,   73,   70,   74,   64,
       79,   37,    0,   76,   37,   35,    0,   45,   66,   71,
       65,   48,   48,   67,    1,   33,   34,    1,    2,   37,
       35,   30,   39,   40,    7,   15,   13,    0,  102,    0,
       37,    2,   37,    0,    0,    0,   98,   97,   10,    0,
        0,    0,    5,    0,    4,    3,   27,   26,   29,    9,
        0,    0,    0,   19,    0,    0,   18,    0,   20,   21,

        0,    0,   96,    0,    0,    2,   37,    0,   47,   47,
        0,    0,    0,    0,    0,   78,    0,   44,   37,    0,
       38,   45,   48,    1,    1,    2,   37,   35,   39,    0,
        0,    0,  101,    2,   37,  100,    0,   12,    0,    0,
        3,    0,   11,    0,    0,    0,   22,    0,    0,   21,
        0,    0,   47,   47,    0,    0,    0,    0,    0,    0,
        0,   48,    0,   37,   39,    0,    0,    0,   39,  101,
      101,  100,  100,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   21,    0,    0,   47,    0,
       90,   92,    0,    0,    0,    0,    0,   48,    0,   37,

       39,    0,    0,    0,    0,    0,   12,    0,    0,    0,
        0,   11,    0,    0,    0,    0,   22,    0,    0,    0,
        0,    0,    0,   90,   92,    0,   86,    0,    0,    0,
       48,    0,    0,    0,    0,    0,    0,   39,    0,    0,
        0,    0,    0,   82,    0,   94,   86,   88,    0,    0,
       42,   36,    0,    0,    0,    0,    0,    0,   46,   82,
       88,   84,   42,   42,   48,   48,   48,   36,   39,    0,
        0,    0,   46,   46,   84,    0,    0,   48,   48,   48,
       48,   48,   36,   39,    0,    0,    0,    0,    0,   48,
       48,   48,   48,   48,   48,   48,    0,    0,    0,    0,

        0,    0,    0,   48,   48,   48,   48,   48,   48,   48,
       89,    0,    0,    0,    0,    0,    0,   48,   89,    0,
       91,   48,   48,   48,   48,    0,   85,    0,    0,    0,
       48,    0,   93,   85,   48,   48,   87,   81,    0,   81,
       87,   48,   83,   83,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    8,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   21,
       21,   21,   21,   21,   21,   22,   22,   23,   24,   25,
       26,   27,   28,   28,   29,   30,   31,   32,   33,   34,
       35,   35,   36,   35,   35,   37,   35,   38,   35,   35,
       39,   35,   40,   35,   41,   35,   35,   42,   35,   35,
       43,   44,   45,   46,   35,   28,   29,   30,   31,   32,

       33,   34,   35,   35,   36,   35,   35,   37,   35,   38,
       35,   35,   39,   35,   40,   35,   41,   35,   35,   42,
       35,   35,   47,   48,   49,   28,    1,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,

       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35,   35,   35,   35,   35,   35,
       35,   35,   35,   35,   35
    } ;

static yyconst flex_int32_t yy_meta[50] =
    {   0,
        1,    2,    3,    4,    5,    6,    5,    7,    8,    5,
        9,   10,   10,   11,    8,    1,   12,   13,   11,   14,
       14,   14,   15,   16,   17,    5,   18,    5,   19,   19,
       19,   19,   19,   19,   20,   20,   20,   20,   20,   20,
       20,   20,   21,   22,   10,    5,    1,    5,    1
    } ;

static yyconst flex_int16_t yy_base[489] =
    {   0,
        0,    5,   27,    0,   76,    0,  120,  142,  168,  191,
      198,    0, 1433, 1432,  236,  280, 1435, 1434,  121,  124,
     1428, 1427,  132,  135,    0,    0,  300,    0,  147,  150,
     1437, 1997,  111, 1422,  178, 1997,    0,    6, 1389, 1997,
       92,  141, 1147, 1162, 1997, 1997, 1997, 1138,  176, 1997,
      158,  183,  228,  238,  248, 1997, 1138, 1132, 1130,    0,
     1113, 1997, 1997, 1997, 1084, 1997, 1997,   12,  204,    0,
     1997,  201,    0, 1997, 1997, 1114,  204, 1115,  255, 1081,
        0, 1090, 1085, 1084, 1067,    0,  280,  243,  291,    0,
     1997,  319,  271, 1076,  296, 1997,    0,    0,  342,    0,

        0,  115, 1073,    0, 1080, 1997, 1997,  208,    0,  345,
        0,  349,  136,  352, 1997, 1997, 1997,  145, 1039,  343,
        0,  347,  352,  375,  242, 1997, 1026,  281,  381, 1036,
      211,  245, 1997, 1997, 1997, 1997, 1997, 1997, 1997, 1052,
     1997,  366, 1059, 1997,  369,  374,  383,    0, 1997, 1997,
     1997,    0, 1028, 1997,  406,    0,  391,  421,    0,  394,
      399, 1997,  363,    0, 1997, 1997, 1997, 1011, 1997, 1028,
      421,  465,  430,  435, 1005,  420, 1997,    0,    0,  459,
      483, 1012,    0,  284, 1997,    0,    0, 1997, 1997,    0,
      493,  501, 1011,    0,  504,  512, 1997, 1008, 1997,  337,

      522,  528, 1997,  990,  981,    0,  444,  427,  962,  961,
      954,  284,  945,  401,  941, 1997,  964, 1997,  514,  517,
      520,    0,  929,    0,  548,    0,  548,  562,  484,  927,
        0,  547,  575,    0,  565,  598,  601, 1997,  936,  604,
        0,  612, 1997,  927,  607,  623, 1997,  921,  628,  457,
      906,  228,  884,  633,  889,  890,  889,  885,  879,  874,
      868,  557,  523,  621,  629,  646,  649,  653,  656,  665,
     1997,  676, 1997,  679,  700,  703,  706,  710,  722,  726,
      729,  733,  738,  745,  749, 1997,  682,  393,  852,  857,
      754,  757,  852,  842,  842,  829,  761,  830,  749,  754,

      644,  801,  834,  675,  775,  778,  851,  854,  781,  870,
      880,  890,  900,  896,  912,  916,  928,  932,  938,  886,
      828,  632,  833,  876,  906,  944,  948,  830,  831,  761,
      762,  936,  941,  780,  779,  777,    0,  842,  962,  967,
      972,  756,  317,  978,  983, 1997,  988,  991,  758,  753,
      994,  979,  770,    0,  746, 1014,  751, 1000, 1013, 1006,
     1009, 1016, 1035, 1056,  721,  461,  337, 1001, 1085, 1061,
      482,  711, 1038, 1070, 1073,  705,  359,  700,  577,  687,
      490,  666, 1997,    0,  635,  663,  516,  654,  634,  608,
      604,  600,  592,  587,  587,  561,  559,  558,  554,  555,

      524,  497,  480,  471, 1076, 1106,  454,  449,  448,  419,
     1081, 1109,  395,  384,  368,  289,  269,  263, 1096, 1132,
     1997, 1135, 1138,  240,  212, 1141, 1144,  167,  149,  127,
     1147, 1150, 1997, 1158, 1164,  104, 1167, 1173,  102, 1176,
     1179, 1182, 1185, 1188, 1997, 1192, 1214, 1236, 1258, 1280,
     1302, 1324, 1346, 1368, 1390, 1412, 1428, 1444,  696, 1456,
     1476, 1498, 1520, 1536, 1556, 1578, 1600, 1622, 1644, 1665,
     1686, 1702, 1720,  454, 1742, 1760, 1772, 1789, 1807,  552,
     1828, 1849, 1871, 1893, 1909, 1930, 1952, 1974
    } ;

static yyconst flex_int16_t yy_def[489] =
    {   0,
      446,  446,  445,    3,  445,    5,  447,  447,  448,  448,
      446,   11,  449,  449,  450,  450,  451,  451,  452,  452,
      453,  453,  454,  454,  446,  446,  446,   27,  455,  455,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      456,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  457,
      457,  445,  445,  445,  445,  445,  445,  445,  445,  458,
      445,  445,  458,  445,  445,  458,  445,  458,  445,  459,
      460,  460,  460,  460,  461,  462,  461,  461,  461,  463,
      445,  445,  445,  445,  445,  445,  464,  465,  445,  466,

      466,  445,  445,  467,  445,  445,  445,  445,  468,  445,
      469,  445,  470,  471,  445,  445,  445,  445,  445,  445,
      472,  445,  445,  445,  456,  445,  456,  456,  456,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  473,  445,  445,  445,  445,  474,  445,  445,
      445,  457,  457,  445,  445,  458,  445,  475,  476,  445,
      445,  445,  477,  460,  445,  445,  445,  461,  445,  462,
      461,  461,  461,  461,  463,  445,  445,  464,  465,  445,
      445,  445,  466,  445,  445,  478,  467,  445,  445,  468,
      445,  445,  445,  469,  445,  445,  445,  445,  445,  445,

      445,  471,  445,  445,  445,  472,  445,  456,  479,  479,
      445,  445,  445,  445,  445,  445,  473,  445,  445,  445,
      445,  474,  457,  475,  475,  476,  445,  445,  477,  445,
      480,  481,  445,  172,  461,  445,  445,  445,  445,  482,
      478,  445,  445,  445,  483,  445,  445,  445,  484,  445,
      445,  456,  479,  479,  445,  445,  445,  445,  445,  445,
      445,  457,  445,  445,  485,  481,  481,  481,  481,  445,
      445,  445,  445,  486,  482,  482,  482,  487,  483,  483,
      483,  488,  484,  484,  484,  445,  445,  456,  479,  445,
      445,  445,  445,  445,  445,  445,  445,  457,  445,  445,

      485,  445,  269,  269,  486,  486,  486,  486,  482,  487,
      487,  487,  487,  483,  488,  488,  488,  488,  484,  445,
      445,  456,  445,  445,  445,  445,  445,  445,  445,  445,
      457,  445,  445,  302,  302,  302,  302,  302,  486,  487,
      488,  445,  456,  445,  445,  445,  445,  445,  445,  445,
      457,  445,  445,  302,  302,  302,  302,  445,  456,  445,
      445,  445,  445,  445,  457,  457,  457,  445,  302,  445,
      445,  445,  456,  445,  445,  445,  445,  457,  457,  457,
      457,  457,  445,  369,  445,  445,  445,  445,  445,  457,
      457,  457,  457,  457,  457,  457,  445,  445,  445,  445,

      445,  445,  445,  457,  457,  457,  457,  457,  457,  457,
      445,  445,  445,  445,  445,  445,  445,  457,  445,  445,
      445,  457,  457,  457,  457,  445,  445,  445,  445,  445,
      457,  445,  445,  445,  457,  457,  445,  445,  445,  445,
      445,  457,  445,  445,    0,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445
    } ;

static yyconst flex_int16_t yy_nxt[2047] =
    {   0,
      445,  124,  124,  124,  445,  445,  125,  124,  124,  124,
      445,  445,  125,  155,  155,  155,  445,   33,   34,   35,
       35,   35,   33,   34,   35,   35,   35,   36,   37,   38,
       37,   39,   40,   41,   42,   43,   44,   45,   46,   47,
       48,   49,   50,   51,   52,   53,   54,   55,   55,   36,
       56,   57,   58,   59,   36,   60,   60,   60,   60,   61,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   62,
       36,   63,   36,   64,   65,   66,   67,   68,   69,   68,
       70,   71,   70,   72,   73,   70,   74,   75,   75,   73,
       73,   75,   76,   77,   78,   79,   79,   79,   80,   75,

       73,   73,   73,   70,   81,   82,   81,   81,   81,   81,
       81,   81,   81,   83,   81,   81,   81,   84,   75,   67,
       75,   73,   67,   70,   67,   86,  107,  128,  184,  107,
      120,  120,  120,  185,  443,  129,  442,   87,   88,   89,
       89,   89,  112,   32,   90,  112,   32,   86,  116,  117,
      116,  116,  117,  116,  118,  200,  200,  118,  439,   87,
       88,   89,   89,   89,  108,   32,   90,  108,   32,   92,
       92,   92,  130,  131,  138,  113,  132,  131,  113,  119,
      204,  438,  119,  139,  140,   93,   94,   95,   95,   95,
      136,   96,   92,   92,   92,  122,  141,  123,  123,  123,

      437,  137,  142,  142,  142,  155,  155,  155,   93,   94,
       95,   95,   95,  189,   96,   33,   34,   35,   35,   35,
      157,  157,  157,  142,  142,  142,   97,   97,   97,   97,
       97,   97,   97,   97,   97,   97,   97,   97,   97,   97,
      101,  121,  101,  436,  101,  101,  143,  212,  213,  102,
      101,  189,  101,  144,  103,  145,  172,  146,  146,  146,
      101,  101,  101,  101,  288,  145,  169,  146,  146,  146,
      147,  129,  160,  435,  161,  161,  161,  128,  214,  148,
      147,  101,  215,  101,  101,  129,  101,  147,  101,  101,
      120,  120,  120,  102,  101,  431,  101,  184,  103,  171,

      171,  171,  185,  169,  101,  101,  101,  101,  173,  430,
      174,  174,  174,  122,  169,  123,  123,  123,  208,  256,
      176,  176,  176,  257,  129,  101,  429,  101,  114,  114,
      114,  114,  114,  114,  114,  114,  114,  114,  114,  114,
      114,  114,  177,  180,  181,  181,  191,  192,  192,  359,
      195,  196,  196,  201,  201,  201,  250,  250,  182,  197,
      129,  193,  120,  120,  120,  198,  207,  207,  207,  122,
      381,  123,  123,  123,  382,  203,  124,  124,  124,  230,
      231,  125,  209,  210,  209,  142,  142,  142,  219,  219,
      219,  145,  387,  146,  146,  146,  389,  220,  147,  220,

      428,  147,  221,  221,  221,  232,  147,  155,  155,  155,
      157,  157,  157,  227,  227,  227,  160,  427,  228,  228,
      228,  176,  176,  176,  129,  225,  147,  225,  426,  225,
      225,  147,  259,  322,  225,  225,  129,  225,  260,  225,
      171,  171,  171,  177,  169,  225,  225,  225,  225,  235,
      235,  235,  173,  169,  174,  174,  174,  252,  169,  425,
      180,  181,  181,  207,  207,  207,  225,  222,  225,  234,
      129,  234,  222,  234,  234,  182,  286,  286,  234,  234,
      424,  234,  423,  234,  237,  237,  237,  422,  169,  206,
      234,  206,  234,  238,  191,  192,  192,  379,  380,  239,

      230,  231,  242,  242,  242,  195,  196,  196,  418,  193,
      234,  243,  234,  246,  246,  246,  417,  244,  385,  386,
      198,  394,  247,  201,  201,  201,  232,  395,  248,  201,
      201,  201,  416,  219,  219,  219,  221,  221,  221,  221,
      221,  221,  299,  299,  299,  203,  147,  400,  266,  266,
      266,  203,  225,  401,  225,  415,  225,  225,  297,  297,
      297,  225,  225,  268,  225,  263,  225,  264,  264,  264,
      265,  265,  225,  225,  225,  225,  270,  270,  270,  160,
      147,  146,  146,  146,  235,  235,  235,  414,  169,  413,
      412,  269,  411,  225,  147,  225,  298,  410,  271,  272,

      272,  272,  237,  237,  237,  276,  181,  181,  280,  192,
      192,  238,  391,  242,  242,  242,  392,  239,  409,  408,
      277,  273,  243,  281,  246,  246,  246,  407,  244,  284,
      196,  196,  406,  247,  289,  210,  289,  405,  263,  248,
      300,  300,  300,  404,  285,  230,  231,  266,  266,  266,
      266,  266,  266,  147,  266,  266,  266,  266,  266,  266,
      230,  231,  268,  343,  403,  268,  270,  270,  270,  302,
      397,  232,  303,  231,  398,  129,  254,  272,  272,  272,
      306,  237,  237,  320,  320,  320,  232,  402,  271,  307,
      269,  268,  445,  269,  399,  308,  396,  269,  304,  273,

      269,  276,  181,  181,  276,  181,  181,  276,  181,  181,
      163,  311,  242,  242,  163,  163,  277,  267,  393,  277,
      312,  321,  309,  280,  192,  192,  313,  280,  192,  192,
      280,  192,  192,  390,  316,  246,  246,  388,  281,  284,
      196,  196,  281,  317,  387,  314,  284,  196,  196,  318,
      284,  196,  196,  378,  285,  324,  324,  324,  325,  325,
      325,  285,  297,  297,  297,  319,  332,  354,  333,  333,
      333,  263,  356,  219,  219,  219,  306,  237,  237,  306,
      237,  237,  276,  181,  181,  307,  147,  332,  307,  363,
      362,  308,  358,  354,  308,  354,  354,  309,  351,  350,

      330,  334,  335,  266,  266,  334,  334,  334,  336,  336,
      334,  334,  336,  336,  336,  336,  334,  337,  334,  336,
      336,  336,  336,  334,  334,  334,  334,  334,  334,  336,
      336,  336,  336,  336,  336,  336,  336,  336,  336,  336,
      336,  336,  336,  336,  334,  338,  334,  334,  334,  334,
      302,  445,  306,  237,  237,  306,  237,  237,  355,  356,
      231,  307,  349,  348,  307,  344,  342,  308,  331,  329,
      339,  311,  242,  242,  328,  327,  267,  324,  324,  324,
      312,  311,  242,  242,  357,  326,  313,  320,  320,  320,
      312,  311,  242,  242,  323,  254,  313,  280,  192,  192,

      312,  311,  242,  242,  296,  295,  313,  325,  325,  325,
      312,  294,  314,  316,  246,  246,  340,  316,  246,  246,
      293,  292,  317,  291,  290,  321,  317,  254,  318,  316,
      246,  246,  318,  316,  246,  246,  287,  282,  317,  284,
      196,  196,  317,  278,  318,  345,  345,  345,  341,  347,
      347,  347,  274,  231,  319,  352,  352,  352,  332,  262,
      353,  353,  353,  306,  237,  237,  218,  346,  311,  242,
      242,  261,  307,  316,  246,  246,  258,  312,  339,  360,
      360,  360,  317,  340,  345,  345,  345,  255,  341,  347,
      347,  347,  361,  361,  361,  364,  364,  364,  368,  368,

      368,  370,  370,  370,  254,  254,  346,  360,  360,  360,
      361,  361,  361,  251,  373,  374,  373,  375,  375,  375,
      383,  383,  383,  214,  249,  365,  366,  245,  240,  367,
      354,  236,  371,  233,  169,  372,  364,  364,  364,  373,
      374,  373,  369,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  129,  364,  364,  364,
      223,  218,  370,  370,  370,  216,  376,  371,  211,  129,
      377,  374,  374,  374,  375,  375,  375,  419,  419,  419,
      205,  129,  419,  419,  419,  188,  186,  376,  371,  121,
      169,  377,  384,  371,  167,  166,  372,  419,  419,  419,

      165,  355,  356,  162,  384,  384,  384,  420,  420,  420,
      420,  420,  420,  384,  384,  384,  384,  384,  384,  384,
      384,  384,  384,  384,  384,  384,  384,  357,  159,  421,
      158,  154,  421,  420,  420,  420,  432,  432,  432,  434,
      434,  434,  432,  432,  432,  434,  434,  434,  440,  440,
      440,  432,  432,  432,  153,  421,  151,  150,  433,  434,
      434,  434,  149,  135,  433,  441,  441,  441,  441,  441,
      441,  134,  133,  433,  440,  440,  440,  440,  440,  440,
      441,  441,  441,  444,  444,  444,  444,  444,  444,  444,
      444,  444,   32,   32,   32,   32,   32,   32,   32,   32,

       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   91,   91,   91,   91,
       91,   91,   91,   91,   91,   91,   91,   91,   91,   91,
       91,   91,   91,   91,   91,   91,   91,   91,   98,   98,
       98,   98,   98,   98,   98,   98,   98,   98,   98,   98,
       98,   98,   98,   98,   98,   98,   98,   98,   98,   98,
      100,  100,  100,  100,  100,  100,  100,  100,  100,  100,
      100,  100,  100,  100,  100,  100,  100,  100,  100,  100,

      100,  100,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  106,  109,  109,  109,  109,
      109,  109,  109,  109,  109,  109,  109,  109,  109,  109,
      109,  109,  109,  109,  109,  109,  109,  109,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,

      115,  115,  115,  115,  115,  115,  115,  115,  115,  115,
      115,  115,  127,  127,  126,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  152,  121,  445,  110,  110,  105,
      105,  152,   99,   99,  445,  445,  152,  152,  156,  445,
      445,  156,  445,  445,  156,  156,  445,  445,  445,  445,
      156,  156,  164,  445,  445,  445,  445,  445,  445,  164,
      445,  445,  445,  445,  164,  164,  168,  168,  168,  168,
      168,  445,  168,  168,  168,  168,  168,  168,  168,  168,
      168,  168,  445,  445,  168,  168,  168,  168,  170,  170,

      170,  170,  170,  445,  170,  170,  170,  170,  170,  170,
      170,  170,  170,  170,  170,  170,  170,  170,  170,  170,
      175,  175,  175,  175,  175,  175,  175,  175,  175,  175,
      175,  175,  175,  175,  175,  175,  175,  445,  175,  175,
      175,  175,  178,  445,  445,  445,  445,  445,  445,  178,
      445,  445,  445,  445,  178,  178,  179,  179,  179,  179,
      179,  179,  179,  179,  445,  179,  179,  179,  179,  179,
      179,  179,  179,  179,  179,  179,  179,  179,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  445,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,

      187,  187,  187,  187,  187,  445,  187,  187,  187,  187,
      187,  187,  187,  187,  187,  187,  187,  187,  187,  187,
      187,  187,  190,  190,  190,  190,  190,  190,  190,  190,
      445,  190,  190,  190,  190,  190,  190,  190,  190,  190,
      190,  190,  190,  190,  194,  194,  194,  194,  194,  194,
      194,  194,  445,  194,  194,  194,  194,  194,  194,  194,
      194,  194,  194,  194,  194,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  202,  202,  202,
      445,  445,  202,  445,  445,  445,  445,  445,  445,  202,

      445,  202,  445,  445,  202,  202,  206,  445,  445,  206,
      445,  445,  206,  206,  445,  445,  445,  445,  206,  206,
      217,  217,  217,  217,  217,  217,  217,  217,  217,  217,
      217,  217,  217,  217,  217,  217,  217,  217,  217,  217,
      217,  217,  224,  224,  445,  445,  224,  224,  224,  224,
      224,  224,  224,  224,  224,  224,  224,  224,  224,  224,
      224,  224,  224,  224,  226,  445,  445,  226,  445,  445,
      226,  226,  445,  445,  445,  445,  226,  226,  229,  445,
      445,  445,  445,  229,  229,  229,  445,  445,  445,  445,
      229,  229,  229,  241,  445,  445,  241,  445,  445,  241,

      241,  445,  445,  445,  445,  241,  241,  253,  253,  445,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  253,  253,  253,  253,  267,
      267,  267,  445,  445,  267,  267,  445,  267,  267,  267,
      445,  267,  445,  445,  445,  445,  267,  267,  267,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  275,  275,  275,  275,  275,
      275,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  279,  283,  283,  283,  283,  283,  283,  283,

      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  301,  445,  445,  445,  445,
      301,  301,  301,  445,  445,  445,  445,  301,  301,  301,
      305,  305,  305,  305,  305,  305,  305,  305,  305,  305,
      305,  305,  305,  305,  305,  305,  305,  305,  305,  305,
      305,  305,  310,  310,  310,  310,  310,  310,  310,  310,
      310,  310,  310,  310,  310,  310,  310,  310,  310,  310,
      310,  310,  310,  310,  315,  315,  315,  315,  315,  315,
      315,  315,  315,  315,  315,  315,  315,  315,  315,  315,
      315,  315,  315,  315,  315,  315,   31,  445,  445,  445,

      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445
    } ;

static yyconst flex_int16_t yy_chk[2047] =
    {   0,
        0,   37,   37,   37,    0,    0,   37,   38,   38,   38,
        0,    0,   38,   68,   68,   68,    0,    1,    1,    1,
        1,    1,    2,    2,    2,    2,    2,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    7,   19,   41,  102,   20,
       33,   33,   33,  102,  439,   41,  436,    7,    7,    7,
        7,    7,   23,    7,    7,   24,    7,    8,   29,   29,
       29,   30,   30,   30,   29,  113,  113,   30,  430,    8,
        8,    8,    8,    8,   19,    8,    8,   20,    8,    9,
        9,    9,   42,   42,   51,   23,   42,  118,   24,   29,
      118,  429,   30,   51,   51,    9,    9,    9,    9,    9,
       49,    9,   10,   10,   10,   35,   52,   35,   35,   35,

      428,   49,   52,   52,   52,   69,   69,   69,   10,   10,
       10,   10,   10,  108,   10,   11,   11,   11,   11,   11,
       72,   72,   72,   77,   77,   77,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       15,   53,   15,  425,   15,   15,   53,  131,  131,   15,
       15,  108,   15,   53,   15,   54,   88,   54,   54,   54,
       15,   15,   15,   15,  252,   55,   88,   55,   55,   55,
       54,  252,   79,  424,   79,   79,   79,  125,  132,   54,
       55,   15,  132,   15,   16,  125,   16,   79,   16,   16,
       93,   93,   93,   16,   16,  418,   16,  184,   16,   87,

       87,   87,  184,   87,   16,   16,   16,   16,   89,  417,
       89,   89,   89,   95,   89,   95,   95,   95,  128,  212,
       92,   92,   92,  212,  128,   16,  416,   16,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       27,   27,   92,   99,   99,   99,  110,  110,  110,  343,
      112,  112,  112,  114,  114,  114,  200,  200,   99,  112,
      343,  110,  120,  120,  120,  112,  122,  122,  122,  123,
      367,  123,  123,  123,  367,  114,  124,  124,  124,  163,
      163,  124,  129,  129,  129,  142,  142,  142,  145,  145,
      145,  146,  377,  146,  146,  146,  377,  147,  142,  147,

      415,  145,  147,  147,  147,  163,  146,  155,  155,  155,
      157,  157,  157,  160,  160,  160,  161,  414,  161,  161,
      161,  176,  176,  176,  129,  158,  160,  158,  413,  158,
      158,  161,  214,  288,  158,  158,  288,  158,  214,  158,
      171,  171,  171,  176,  171,  158,  158,  158,  158,  173,
      173,  173,  174,  173,  174,  174,  174,  208,  174,  410,
      180,  180,  180,  207,  207,  207,  158,  474,  158,  172,
      208,  172,  474,  172,  172,  180,  250,  250,  172,  172,
      409,  172,  408,  172,  181,  181,  181,  407,  172,  172,
      172,  172,  172,  181,  191,  191,  191,  366,  366,  181,

      229,  229,  192,  192,  192,  195,  195,  195,  404,  191,
      172,  192,  172,  196,  196,  196,  403,  192,  371,  371,
      195,  381,  196,  201,  201,  201,  229,  381,  196,  202,
      202,  202,  402,  219,  219,  219,  220,  220,  220,  221,
      221,  221,  263,  263,  263,  201,  219,  387,  232,  232,
      232,  202,  225,  387,  225,  401,  225,  225,  262,  262,
      262,  225,  225,  232,  225,  227,  225,  227,  227,  227,
      480,  480,  225,  225,  225,  225,  233,  233,  233,  228,
      227,  228,  228,  228,  235,  235,  235,  400,  235,  399,
      398,  232,  397,  225,  228,  225,  262,  396,  233,  236,

      236,  236,  237,  237,  237,  240,  240,  240,  245,  245,
      245,  237,  379,  242,  242,  242,  379,  237,  395,  394,
      240,  236,  242,  245,  246,  246,  246,  393,  242,  249,
      249,  249,  392,  246,  254,  254,  254,  391,  264,  246,
      264,  264,  264,  390,  249,  265,  265,  266,  266,  266,
      267,  267,  267,  264,  268,  268,  268,  269,  269,  269,
      301,  301,  266,  322,  389,  267,  270,  270,  270,  268,
      385,  265,  269,  269,  385,  322,  254,  272,  272,  272,
      274,  274,  274,  287,  287,  287,  301,  388,  270,  274,
      266,  304,  304,  267,  386,  274,  382,  268,  269,  272,

      269,  275,  275,  275,  276,  276,  276,  277,  277,  277,
      459,  278,  278,  278,  459,  459,  275,  304,  380,  276,
      278,  287,  277,  279,  279,  279,  278,  280,  280,  280,
      281,  281,  281,  378,  282,  282,  282,  376,  279,  283,
      283,  283,  280,  282,  372,  281,  284,  284,  284,  282,
      285,  285,  285,  365,  283,  291,  291,  291,  292,  292,
      292,  284,  297,  297,  297,  285,  299,  357,  299,  299,
      299,  300,  355,  300,  300,  300,  305,  305,  305,  306,
      306,  306,  309,  309,  309,  305,  300,  353,  306,  350,
      349,  305,  342,  336,  306,  335,  334,  309,  331,  330,

      297,  302,  302,  302,  302,  302,  302,  302,  302,  302,
      302,  302,  302,  302,  302,  302,  302,  302,  302,  302,
      302,  302,  302,  302,  302,  302,  302,  302,  302,  302,
      302,  302,  302,  302,  302,  302,  302,  302,  302,  302,
      302,  302,  302,  302,  302,  302,  302,  302,  302,  302,
      303,  303,  307,  307,  307,  308,  308,  308,  338,  338,
      303,  307,  329,  328,  308,  323,  321,  307,  298,  296,
      308,  310,  310,  310,  295,  294,  303,  324,  324,  324,
      310,  311,  311,  311,  338,  293,  310,  320,  320,  320,
      311,  312,  312,  312,  290,  289,  311,  314,  314,  314,

      312,  313,  313,  313,  261,  260,  312,  325,  325,  325,
      313,  259,  314,  315,  315,  315,  313,  316,  316,  316,
      258,  257,  315,  256,  255,  320,  316,  253,  315,  317,
      317,  317,  316,  318,  318,  318,  251,  248,  317,  319,
      319,  319,  318,  244,  317,  326,  326,  326,  318,  327,
      327,  327,  239,  230,  319,  332,  332,  332,  333,  223,
      333,  333,  333,  339,  339,  339,  217,  326,  340,  340,
      340,  215,  339,  341,  341,  341,  213,  340,  339,  344,
      344,  344,  341,  340,  345,  345,  345,  211,  341,  347,
      347,  347,  348,  348,  348,  351,  351,  351,  352,  352,

      352,  358,  358,  358,  210,  209,  345,  360,  360,  360,
      361,  361,  361,  205,  359,  359,  359,  362,  362,  362,
      368,  368,  368,  204,  198,  351,  351,  193,  182,  351,
      356,  175,  358,  170,  168,  358,  363,  363,  363,  373,
      373,  373,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  359,  364,  364,  364,
      153,  143,  370,  370,  370,  140,  363,  363,  130,  127,
      363,  374,  374,  374,  375,  375,  375,  405,  405,  405,
      119,  373,  411,  411,  411,  105,  103,  364,  364,   94,
       85,  364,  369,  370,   84,   83,  370,  419,  419,  419,

       82,  369,  369,   80,  369,  369,  369,  406,  406,  406,
      412,  412,  412,  369,  369,  369,  369,  369,  369,  369,
      369,  369,  369,  369,  369,  369,  369,  369,   78,  406,
       76,   65,  412,  420,  420,  420,  422,  422,  422,  423,
      423,  423,  426,  426,  426,  427,  427,  427,  431,  431,
      431,  432,  432,  432,   61,  420,   59,   58,  422,  434,
      434,  434,   57,   48,  426,  435,  435,  435,  437,  437,
      437,   44,   43,  432,  438,  438,  438,  440,  440,  440,
      441,  441,  441,  442,  442,  442,  443,  443,  443,  444,
      444,  444,  446,  446,  446,  446,  446,  446,  446,  446,

      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  447,  447,  447,  447,
      447,  447,  447,  447,  447,  447,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  448,  448,  448,  448,
      448,  448,  448,  448,  448,  448,  448,  448,  449,  449,
      449,  449,  449,  449,  449,  449,  449,  449,  449,  449,
      449,  449,  449,  449,  449,  449,  449,  449,  449,  449,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  450,
      450,  450,  450,  450,  450,  450,  450,  450,  450,  450,

      450,  450,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  452,  452,  452,  452,
      452,  452,  452,  452,  452,  452,  453,  453,  453,  453,
      453,  453,  453,  453,  453,  453,  453,  453,  453,  453,
      453,  453,  453,  453,  453,  453,  453,  453,  454,  454,
      454,  454,  454,  454,  454,  454,  454,  454,  454,  454,
      454,  454,  454,  454,  454,  454,  454,  454,  454,  454,
      455,  455,  455,  455,  455,  455,  455,  455,  455,  455,

      455,  455,  455,  455,  455,  455,  455,  455,  455,  455,
      455,  455,  456,  456,   39,  456,  456,  456,  456,  456,
      456,  456,  456,  456,  456,  456,  456,  456,  456,  456,
      456,  456,  456,  456,  457,   34,   31,   22,   21,   18,
       17,  457,   14,   13,    0,    0,  457,  457,  458,    0,
        0,  458,    0,    0,  458,  458,    0,    0,    0,    0,
      458,  458,  460,    0,    0,    0,    0,    0,    0,  460,
        0,    0,    0,    0,  460,  460,  461,  461,  461,  461,
      461,    0,  461,  461,  461,  461,  461,  461,  461,  461,
      461,  461,    0,    0,  461,  461,  461,  461,  462,  462,

      462,  462,  462,    0,  462,  462,  462,  462,  462,  462,
      462,  462,  462,  462,  462,  462,  462,  462,  462,  462,
      463,  463,  463,  463,  463,  463,  463,  463,  463,  463,
      463,  463,  463,  463,  463,  463,  463,    0,  463,  463,
      463,  463,  464,    0,    0,    0,    0,    0,    0,  464,
        0,    0,    0,    0,  464,  464,  465,  465,  465,  465,
      465,  465,  465,  465,    0,  465,  465,  465,  465,  465,
      465,  465,  465,  465,  465,  465,  465,  465,  466,  466,
      466,  466,  466,  466,  466,  466,  466,  466,    0,  466,
      466,  466,  466,  466,  466,  466,  466,  466,  466,  466,

      467,  467,  467,  467,  467,    0,  467,  467,  467,  467,
      467,  467,  467,  467,  467,  467,  467,  467,  467,  467,
      467,  467,  468,  468,  468,  468,  468,  468,  468,  468,
        0,  468,  468,  468,  468,  468,  468,  468,  468,  468,
      468,  468,  468,  468,  469,  469,  469,  469,  469,  469,
      469,  469,    0,  469,  469,  469,  469,  469,  469,  469,
      469,  469,  469,  469,  469,  470,  470,  470,  470,  470,
      470,  470,  470,  470,  470,  470,  470,  470,  470,  470,
      470,  470,  470,  470,  470,  470,  470,  471,  471,  471,
        0,    0,  471,    0,    0,    0,    0,    0,    0,  471,

        0,  471,    0,    0,  471,  471,  472,    0,    0,  472,
        0,    0,  472,  472,    0,    0,    0,    0,  472,  472,
      473,  473,  473,  473,  473,  473,  473,  473,  473,  473,
      473,  473,  473,  473,  473,  473,  473,  473,  473,  473,
      473,  473,  475,  475,    0,    0,  475,  475,  475,  475,
      475,  475,  475,  475,  475,  475,  475,  475,  475,  475,
      475,  475,  475,  475,  476,    0,    0,  476,    0,    0,
      476,  476,    0,    0,    0,    0,  476,  476,  477,    0,
        0,    0,    0,  477,  477,  477,    0,    0,    0,    0,
      477,  477,  477,  478,    0,    0,  478,    0,    0,  478,

      478,    0,    0,    0,    0,  478,  478,  479,  479,    0,
      479,  479,  479,  479,  479,  479,  479,  479,  479,  479,
      479,  479,  479,  479,  479,  479,  479,  479,  479,  481,
      481,  481,    0,    0,  481,  481,    0,  481,  481,  481,
        0,  481,    0,    0,    0,    0,  481,  481,  481,  482,
      482,  482,  482,  482,  482,  482,  482,  482,  482,  482,
      482,  482,  482,  482,  482,  482,  482,  482,  482,  482,
      482,  483,  483,  483,  483,  483,  483,  483,  483,  483,
      483,  483,  483,  483,  483,  483,  483,  483,  483,  483,
      483,  483,  483,  484,  484,  484,  484,  484,  484,  484,

      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  485,    0,    0,    0,    0,
      485,  485,  485,    0,    0,    0,    0,  485,  485,  485,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  486,  486,  486,  486,  486,  486,  486,  486,
      486,  486,  487,  487,  487,  487,  487,  487,  487,  487,
      487,  487,  487,  487,  487,  487,  487,  487,  487,  487,
      487,  487,  487,  487,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  488,  488,  488,  488,
      488,  488,  488,  488,  488,  488,  445,  445,  445,  445,

      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[104] =
    {   0,
1, 0, 0, 0, 1, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 
    1, 0, 1, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
    0, 0, 1, 0, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1, 1, 
    1, 1, 1, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "pgc.l"
#line 2 "pgc.l"
/*-------------------------------------------------------------------------
 *
 * pgc.l
 *	  lexical scanner for ecpg
 *
 * This is a modified version of src/backend/parser/scan.l
 *
 *
 * Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 *
 * IDENTIFICATION
 *	  $PostgreSQL: pgsql/src/interfaces/ecpg/preproc/pgc.l,v 1.122.2.3 2004/07/20 18:22:53 meskes Exp $
 *
 *-------------------------------------------------------------------------
 */
#include "postgres_fe.h"

#include <ctype.h>
#include <sys/types.h>
#include <limits.h>
#include <errno.h>

#include "extern.h"

extern YYSTYPE yylval;

static int		xcdepth = 0;	/* depth of nesting in slash-star comments */

/*
 * literalbuf is used to accumulate literal values when multiple rules
 * are needed to parse a single literal.  Call startlit to reset buffer
 * to empty, addlit to add text.  Note that the buffer is permanently
 * malloc'd to the largest size needed so far in the current run.
 */
static char    *literalbuf = NULL;		/* expandable buffer */
static int		literallen;				/* actual current length */
static int		literalalloc;			/* current allocated buffer size */

#define startlit()	(literalbuf[0] = '\0', literallen = 0)
static void addlit(char *ytext, int yleng);
static void addlitchar (unsigned char);
static void parse_include (void);

char *token_start;
int state_before;

struct _yy_buffer 
{ 
	YY_BUFFER_STATE		buffer;
	long				lineno;
	char		  		*filename;
	struct _yy_buffer 	*next;
} *yy_buffer = NULL;

static char *old;

#define MAX_NESTED_IF 128
static short preproc_tos;
static short ifcond;
static struct _if_value 
{
	short condition;
	short else_branch;
} stacked_if_value[MAX_NESTED_IF];


/*
 * OK, here is a short description of lex/flex rules behavior.
 * The longest pattern which matches an input string is always chosen.
 * For equal-length patterns, the first occurring in the rules list is chosen.
 * INITIAL is the starting state, to which all non-conditional rules apply.
 * Exclusive states change parsing rules while the state is active.  When in
 * an exclusive state, only those rules defined for that state apply.
 *
 * We use exclusive states for quoted strings, extended comments,
 * and to eliminate parsing troubles for numeric strings.
 * Exclusive states:
 *	<xb> bit string literal
 *	<xc> extended C-style comments - thomas 1997-07-12
 *	<xd> delimited identifiers (double-quoted identifiers) - thomas 1997-10-27
 *	<xh> hexadecimal numeric string - thomas 1997-11-16
 *	<xq> quoted strings - thomas 1997-07-30
 */









/* Bit string
 */
/* Hexadecimal number
 */
/* National character
 */
/* C version of hex number
 */
/* Extended quote
 * xqdouble implements SQL92 embedded quote
 * xqcat allows strings to cross input lines
 */
/* Double quote
 * Allows embedded spaces and other special characters into identifiers.
 */
/* special stuff for C strings */
/* C-style comments
 *
 * The "extended comment" syntax closely resembles allowable operator syntax.
 * The tricky part here is to get lex to recognize a string starting with
 * slash-star as a comment, when interpreting it as an operator would produce
 * a longer match --- remember lex will prefer a longer match!	Also, if we
 * have something like plus-slash-star, lex will think this is a 3-character
 * operator whereas we want to see it as a + operator and a comment start.
 * The solution is two-fold:
 * 1. append {op_chars}* to xcstart so that it matches as much text as
 *	  {operator} would. Then the tie-breaker (first matching rule of same
 *	  length) ensures xcstart wins.  We put back the extra stuff with yyless()
 *	  in case it contains a star-slash that should terminate the comment.
 * 2. In the operator rule, check for slash-star within the operator, and
 *	  if found throw it back with yyless().  This handles the plus-slash-star
 *	  problem.
 * SQL92-style comments, which start with dash-dash, have similar interactions
 * with the operator rule.
 */
/*
 * "self" is the set of chars that should be returned as single-character
 * tokens.	"op_chars" is the set of chars that can make up "Op" tokens,
 * which can be one or more characters long (but if a single-char token
 * appears in the "self" set, it is not to be returned as an Op).  Note
 * that the sets overlap, but each has some chars that are not in the other.
 *
 * If you change either set, adjust the character lists appearing in the
 * rule for "operator"!
 */
/* we no longer allow unary minus in numbers.
 * instead we pass it separately to parser. there it gets
 * coerced via doNegate() -- Leon aug 20 1999
 */
/*
 * In order to make the world safe for Windows and Mac clients as well as
 * Unix ones, we accept either \n or \r as a newline.  A DOS-style \r\n
 * sequence will be seen as two successive newlines, but that doesn't cause
 * any problems.  SQL92-style comments, which start with -- and extend to the
 * next newline, are treated as equivalent to a single whitespace character.
 *
 * NOTE a fine point: if there is no newline following --, we will absorb
 * everything to the end of the input as a comment.  This is correct.  Older
 * versions of Postgres failed to recognize -- as a comment if the input
 * did not end with a newline.
 *
 * XXX perhaps \f (formfeed) should be treated as a newline as well?
 */
/*
 * SQL92 requires at least one newline in the whitespace separating
 * string literals that are to be concatenated.  Silly, but who are we
 * to argue?  Note that {whitespace_with_newline} should not have * after
 * it, whereas {whitespace} should generally have a * after it...
 */
/* special characters for other dbms */
/* we have to react differently in compat mode */
/* some stuff needed for ecpg */
/* we might want to parse all cpp include files */
/* Take care of cpp continuation lines */
/*
 * Quoted strings must allow some special characters such as single-quote
 *	and newline.
 * Embedded single-quotes are implemented both in the SQL92-standard
 *	style of two adjacent single quotes "''" and in the Postgres/Java style
 *	of escaped-quote "\'".
 * Other embedded escaped characters are matched explicitly and the leading
 *	backslash is dropped from the string. - thomas 1997-09-24
 * Note that xcstart must appear before operator, as explained above!
 *	Also whitespace (comment) must appear before operator.
 */
#line 1260 "pgc.c"

#define INITIAL 0
#define C 1
#define SQL 2
#define incl 3
#define def 4
#define def_ident 5
#define xb 6
#define xc 7
#define xd 8
#define xdc 9
#define xh 10
#define xq 11
#define xpre 12
#define xcond 13
#define xskip 14

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 292 "pgc.l"



                                       /* code to execute during start of each call of yylex() */
                                       token_start = NULL;


#line 1464 "pgc.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 446 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 445 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 299 "pgc.l"
{ /* ignore */ }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 301 "pgc.l"
{
						token_start = yytext;
						state_before = YYSTATE;
						xcdepth = 0;
						BEGIN(xc);
						/* Put back any characters past slash-star; see above */
						yyless(2);
						fputs("/*", yyout);
					}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 310 "pgc.l"
{
						xcdepth++;
				 		/* Put back any characters past slash-star; see above */
				 		yyless(2);
						fputs("/*", yyout);
					}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 317 "pgc.l"
{
						ECHO;
						if (xcdepth <= 0)
						{
							BEGIN(state_before);
							token_start = NULL;
						}
						else
							xcdepth--;
					}
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 328 "pgc.l"
{ ECHO; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 329 "pgc.l"
{ ECHO; }
	YY_BREAK
case YY_STATE_EOF(xc):
#line 331 "pgc.l"
{ mmerror(PARSE_ERROR, ET_FATAL, "Unterminated /* comment"); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 333 "pgc.l"
{
						token_start = yytext;
						BEGIN(xb);
						startlit();
						addlitchar('b');
					}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 339 "pgc.l"
{
						BEGIN(SQL);
						if (literalbuf[strspn(literalbuf, "01") + 1] != '\0')
							mmerror(PARSE_ERROR, ET_ERROR, "invalid bit string input.");
						yylval.str = literalbuf;
						return BCONST;
					}
	YY_BREAK
case 9:
/* rule 9 can match eol */
#line 348 "pgc.l"
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 348 "pgc.l"
{ addlit(yytext, yyleng); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
#line 350 "pgc.l"
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 350 "pgc.l"
{ /* ignore */ }
	YY_BREAK
case YY_STATE_EOF(xb):
#line 351 "pgc.l"
{ mmerror(PARSE_ERROR, ET_FATAL, "Unterminated bit string"); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 353 "pgc.l"
{
						token_start = yytext;
						BEGIN(xh);
						startlit();
						addlitchar('x');
					}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 359 "pgc.l"
{
						yylval.str = literalbuf;
						return XCONST;
					}
	YY_BREAK
case YY_STATE_EOF(xh):
#line 364 "pgc.l"
{ mmerror(PARSE_ERROR, ET_FATAL, "Unterminated hexadecimal integer"); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 365 "pgc.l"
{
				/* National character.
				 * Need to remember type info to flow it forward into the parser.
		                 * Not yet implemented. - thomas 2002-06-17
		                 */
			        token_start = yytext;
				BEGIN(xq);
				startlit();
			}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 374 "pgc.l"
{
						token_start = yytext;
						state_before = YYSTATE;
						BEGIN(xq);
						startlit();
					}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 380 "pgc.l"
{
						BEGIN(state_before);
						yylval.str = mm_strdup(literalbuf);
						return SCONST;
					}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 385 "pgc.l"
{ addlitchar('\''); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 386 "pgc.l"
{ addlit(yytext, yyleng); }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 387 "pgc.l"
{ addlit(yytext, yyleng); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 388 "pgc.l"
{ addlit(yytext, yyleng); }
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 389 "pgc.l"
{ /* ignore */ }
	YY_BREAK
case YY_STATE_EOF(xq):
#line 391 "pgc.l"
{ mmerror(PARSE_ERROR, ET_FATAL, "Unterminated quoted string"); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 393 "pgc.l"
{
						state_before = YYSTATE;
						BEGIN(xd);
						startlit();
					}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 398 "pgc.l"
{
						BEGIN(state_before);
						if (literallen == 0)
							mmerror(PARSE_ERROR, ET_ERROR, "zero-length delimited identifier");
						yylval.str = mm_strdup(literalbuf);
						return CSTRING;
					}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 405 "pgc.l"
{
						BEGIN(state_before);
						yylval.str = mm_strdup(literalbuf);
						return CSTRING;
					}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 410 "pgc.l"
{ addlitchar('"'); }
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 411 "pgc.l"
{ addlit(yytext, yyleng); }
	YY_BREAK
case YY_STATE_EOF(xd):
case YY_STATE_EOF(xdc):
#line 412 "pgc.l"
{ mmerror(PARSE_ERROR, ET_FATAL, "Unterminated quoted identifier"); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 413 "pgc.l"
{
						state_before = YYSTATE;
						BEGIN(xdc);
						startlit();
					}
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 418 "pgc.l"
{ addlit(yytext, yyleng); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 419 "pgc.l"
{ return TYPECAST; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 420 "pgc.l"
{
			  /* are we simulating Informix? */
                          if (INFORMIX_MODE)
			  {
			  	unput(':');
			  }
			  else
				return yytext[0];
			}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 429 "pgc.l"
{ /*
					   * We may find a ';' inside a structure
					   * definition in a TYPE or VAR statement.
					   * This is not an EOL marker.
					   */
					  if (yytext[0] == ';' && struct_level == 0)
						 BEGIN C;
					  return yytext[0];
					}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 438 "pgc.l"
{
						/*
						 * Check for embedded slash-star or dash-dash; those
						 * are comment starts, so operator must stop there.
						 * Note that slash-star or dash-dash at the first
						 * character will match a prior rule, not this one.
						 */
						int		nchars = yyleng;
						char   *slashstar = strstr(yytext, "/*");
						char   *dashdash = strstr(yytext, "--");

						if (slashstar && dashdash)
						{
							/* if both appear, take the first one */
							if (slashstar > dashdash)
								slashstar = dashdash;
						}
						else if (!slashstar)
							slashstar = dashdash;
						if (slashstar)
							nchars = slashstar - yytext;

						/*
						 * For SQL92 compatibility, '+' and '-' cannot be the
						 * last char of a multi-char operator unless the operator
						 * contains chars that are not in SQL92 operators.
						 * The idea is to lex '=-' as two operators, but not
						 * to forbid operator names like '?-' that could not be
						 * sequences of SQL92 operators.
						 */
						while (nchars > 1 &&
							   (yytext[nchars-1] == '+' ||
								yytext[nchars-1] == '-'))
						{
							int		ic;

							for (ic = nchars-2; ic >= 0; ic--)
							{
								if (strchr("~!@#^&|`?%", yytext[ic]))
									break;
							}
							if (ic >= 0)
								break; /* found a char that makes it OK */
							nchars--; /* else remove the +/-, and check again */
						}

						if (nchars < yyleng)
						{
							/* Strip the unwanted chars from the token */
							yyless(nchars);
							/*
							 * If what we have left is only one char, and it's
							 * one of the characters matching "self", then
							 * return it as a character token the same way
							 * that the "self" rule would have.
							 */
							if (nchars == 1 &&
								strchr(",()[].;:+-*/%^<>=", yytext[0]))
								return yytext[0];
						}

						/* Convert "!=" operator to "<>" for compatibility */
						if (strcmp(yytext, "!=") == 0)
							yylval.str = mm_strdup("<>");
						else
							yylval.str = mm_strdup(yytext);
						return Op;
					}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 506 "pgc.l"
{
						yylval.ival = atol(yytext+1);
						return PARAM;
					}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 510 "pgc.l"
{
						long val;
						char* endptr;

						errno = 0;
						val = strtol((char *)yytext, &endptr,10);
						if (*endptr != '\0' || errno == ERANGE
#ifdef HAVE_LONG_INT_64
							/* if long > 32 bits, check for overflow of int4 */
							|| val != (long) ((int32) val)
#endif
							)
						{
							errno = 0;
							yylval.str = mm_strdup(yytext);
							return FCONST;
						}
						yylval.ival = val;
						return ICONST;
					}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 530 "pgc.l"
{
						yylval.str = mm_strdup(yytext);
						return IP;
					}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 534 "pgc.l"
{
						yylval.str = mm_strdup(yytext);
						return FCONST;
					}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 538 "pgc.l"
{
						yylval.str = mm_strdup(yytext);
						return FCONST;
					}
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 542 "pgc.l"
{
						yylval.str = mm_strdup(yytext+1);
						return(CVARIABLE);
					}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 546 "pgc.l"
{
						ScanKeyword    *keyword;
						struct _defines *ptr;

						/* How about a DEFINE? */
						for (ptr = defines; ptr; ptr = ptr->next)
						{
							if (strcmp(yytext, ptr->old) == 0 && ptr->used == NULL)
							{
								struct _yy_buffer *yb;

								yb = mm_alloc(sizeof(struct _yy_buffer));

								yb->buffer =  YY_CURRENT_BUFFER;
								yb->lineno = yylineno;
								yb->filename = mm_strdup(input_filename);
								ptr->used = yb->next = yy_buffer;

								yy_buffer = yb;

								yy_scan_string(ptr->new);
								break;
							}
						}

						if (ptr == NULL)
						{
							/* Is it an SQL keyword? */
							keyword = ScanKeywordLookup(yytext);
							if (keyword != NULL)
								return keyword->value;

							/* Is it an ECPG keyword? */
							keyword = ScanECPGKeywordLookup( yytext);
							if (keyword != NULL)
								return keyword->value;

							/* Is it a C keyword? */
							keyword = ScanCKeywordLookup(yytext);
							if (keyword != NULL)
								return keyword->value;

							/*
							 * None of the above.  Return it as an identifier.
							 *
							 * The backend would attempt to truncate and case-fold
							 * the identifier, but I see no good reason for ecpg
							 * to do so; that's just another way that ecpg could get
							 * out of step with the backend.
							 */
							if (ptr == NULL)
							{
								yylval.str = mm_strdup(yytext);
								return IDENT;
							}
						}
					}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 603 "pgc.l"
{ return yytext[0]; }
	YY_BREAK
case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
#line 604 "pgc.l"
{ BEGIN SQL; return SQL_START; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 605 "pgc.l"
{ 
			  /* are we simulating Informix? */
			  if (INFORMIX_MODE)
			  {
			  	BEGIN SQL;
				return SQL_START;
			  }
			  else
			  	return S_ANYTHING;
			 }
	YY_BREAK
case 44:
/* rule 44 can match eol */
YY_RULE_SETUP
#line 615 "pgc.l"
{ ECHO; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 616 "pgc.l"
{
						char* endptr;

						errno = 0;
						yylval.ival = strtoul((char *)yytext,&endptr,16);
						if (*endptr != '\0' || errno == ERANGE)
						{
							errno = 0;
							yylval.str = mm_strdup(yytext);
							return SCONST;
						}
						return ICONST;
					}
	YY_BREAK
case 46:
/* rule 46 can match eol */
YY_RULE_SETUP
#line 629 "pgc.l"
{
					  if (system_includes)
					  {
					  	BEGIN(incl);
					  }
					  else
					  {
						yylval.str = mm_strdup(yytext);
						return(CPP_LINE);
					  }
			}
	YY_BREAK
case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
#line 640 "pgc.l"
{
						yylval.str = mm_strdup(yytext);
						return(CPP_LINE);
					}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 644 "pgc.l"
{
						ScanKeyword		*keyword;
						struct _defines *ptr;

						/* is it a define? */
						for (ptr = defines; ptr; ptr = ptr->next)
						{
							if (strcmp(yytext, ptr->old) == 0 && ptr->used == NULL)
							{
								struct _yy_buffer *yb;

								yb = mm_alloc(sizeof(struct _yy_buffer));

								yb->buffer =  YY_CURRENT_BUFFER;
								yb->lineno = yylineno;
								yb->filename = mm_strdup(input_filename);
								ptr->used = yb->next = yy_buffer;

								yy_buffer = yb;

								yy_scan_string(ptr->new);
								break;
							}
						}

						if (ptr == NULL)
						{
							keyword = ScanCKeywordLookup(yytext);
							if (keyword != NULL)
								return keyword->value;

							else {
								yylval.str = mm_strdup(yytext);
								return IDENT;
							}
						}
					}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 681 "pgc.l"
{ return(';'); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 682 "pgc.l"
{ return(','); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 683 "pgc.l"
{ return('*'); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 684 "pgc.l"
{ return('%'); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 685 "pgc.l"
{ return('/'); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 686 "pgc.l"
{ return('+'); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 687 "pgc.l"
{ return('-'); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 688 "pgc.l"
{ return('('); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 689 "pgc.l"
{ return(')'); }
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
#line 690 "pgc.l"
{ ECHO; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 691 "pgc.l"
{ return('{'); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 692 "pgc.l"
{ return('}'); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 693 "pgc.l"
{ return('['); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 694 "pgc.l"
{ return(']'); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 695 "pgc.l"
{ return('='); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 696 "pgc.l"
{ return(S_MEMBER); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 697 "pgc.l"
{ return(S_RSHIFT); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 698 "pgc.l"
{ return(S_LSHIFT); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 699 "pgc.l"
{ return(S_OR); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 700 "pgc.l"
{ return(S_AND); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 701 "pgc.l"
{ return(S_INC); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 702 "pgc.l"
{ return(S_DEC); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 703 "pgc.l"
{ return(S_EQUAL); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 704 "pgc.l"
{ return(S_NEQUAL); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 705 "pgc.l"
{ return(S_ADD); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 706 "pgc.l"
{ return(S_SUB); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 707 "pgc.l"
{ return(S_MUL); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 708 "pgc.l"
{ return(S_DIV); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 709 "pgc.l"
{ return(S_MOD); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 710 "pgc.l"
{ return(S_MEMPOINT); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 711 "pgc.l"
{ return(S_DOTPOINT); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 712 "pgc.l"
{ return S_ANYTHING; }
	YY_BREAK
case 81:
/* rule 81 can match eol */
YY_RULE_SETUP
#line 714 "pgc.l"
{ BEGIN(def_ident); }
	YY_BREAK
case 82:
/* rule 82 can match eol */
YY_RULE_SETUP
#line 715 "pgc.l"
{
						/* are we simulating Informix? */
						if (INFORMIX_MODE)
						{
							BEGIN(def_ident);
						}
						else
						{
							yyless(1);
							return (S_ANYTHING);
						}
					}
	YY_BREAK
case 83:
/* rule 83 can match eol */
YY_RULE_SETUP
#line 727 "pgc.l"
{ BEGIN(incl); }
	YY_BREAK
case 84:
/* rule 84 can match eol */
YY_RULE_SETUP
#line 728 "pgc.l"
{ 
					  /* are we simulating Informix? */
					  if (INFORMIX_MODE)
					  {
						  BEGIN(incl);
					  }
					  else
					  {
						  yyless(1);
						  return (S_ANYTHING);
					  }
					}
	YY_BREAK
case 85:
/* rule 85 can match eol */
YY_RULE_SETUP
#line 740 "pgc.l"
{ ifcond = TRUE; BEGIN(xcond); }
	YY_BREAK
case 86:
/* rule 86 can match eol */
YY_RULE_SETUP
#line 741 "pgc.l"
{ 
					  /* are we simulating Informix? */
					  if (INFORMIX_MODE)
					  {
						  ifcond = TRUE;
						  BEGIN(xcond);
					  }
					  else
					  {
						  yyless(1);
						  return (S_ANYTHING);
					  }
					}
	YY_BREAK
case 87:
/* rule 87 can match eol */
YY_RULE_SETUP
#line 754 "pgc.l"
{ ifcond = FALSE; BEGIN(xcond); }
	YY_BREAK
case 88:
/* rule 88 can match eol */
YY_RULE_SETUP
#line 755 "pgc.l"
{ 
					  /* are we simulating Informix? */
					  if (INFORMIX_MODE)
					  {
						  ifcond = FALSE;
						  BEGIN(xcond);
					  }
					  else
					  {
						  yyless(1);
						  return (S_ANYTHING);
					  }
					}
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 768 "pgc.l"
{	/* pop stack */
						if ( preproc_tos == 0 ) {
							mmerror(PARSE_ERROR, ET_FATAL, "Missing matching 'EXEC SQL IFDEF / EXEC SQL IFNDEF'");
						}
						else if ( stacked_if_value[preproc_tos].else_branch )
							mmerror(PARSE_ERROR, ET_FATAL, "Missing 'EXEC SQL ENDIF;'");
						else
							preproc_tos--;

						ifcond = TRUE; BEGIN(xcond);
					}
	YY_BREAK
case 90:
/* rule 90 can match eol */
YY_RULE_SETUP
#line 779 "pgc.l"
{ 
					  /* are we simulating Informix? */
					  if (INFORMIX_MODE)
					  {
						if ( preproc_tos == 0 ) {
							mmerror(PARSE_ERROR, ET_FATAL, "Missing matching 'EXEC SQL IFDEF / EXEC SQL IFNDEF'");
						}
						else if ( stacked_if_value[preproc_tos].else_branch )
							mmerror(PARSE_ERROR, ET_FATAL, "Missing 'EXEC SQL ENDIF;'");
						else
							preproc_tos--;

						ifcond = TRUE; BEGIN(xcond);
					  }
					  else
					  {
						  yyless(1);
						  return (S_ANYTHING);
					  }
					}
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 800 "pgc.l"
{	/* only exec sql endif pops the stack, so take care of duplicated 'else' */
						if ( stacked_if_value[preproc_tos].else_branch ) {
							mmerror(PARSE_ERROR, ET_FATAL, "Duplicated 'EXEC SQL ELSE;'");
						}
						else {
							stacked_if_value[preproc_tos].else_branch = TRUE;
							stacked_if_value[preproc_tos].condition =
							(stacked_if_value[preproc_tos-1].condition &&
							 ! stacked_if_value[preproc_tos].condition);

							if ( stacked_if_value[preproc_tos].condition )
								BEGIN(C);
							else
								BEGIN(xskip);
						}
					}
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 816 "pgc.l"
{
					  /* are we simulating Informix? */
					  if (INFORMIX_MODE)
					  {
						if ( stacked_if_value[preproc_tos].else_branch ) {
							mmerror(PARSE_ERROR, ET_FATAL, "Duplicated 'EXEC SQL ELSE;'");
						}
						else {
							stacked_if_value[preproc_tos].else_branch = TRUE;
							stacked_if_value[preproc_tos].condition =
							(stacked_if_value[preproc_tos-1].condition &&
							 ! stacked_if_value[preproc_tos].condition);

							if ( stacked_if_value[preproc_tos].condition )
								BEGIN(C);
							else
								BEGIN(xskip);
						}
					  }
					  else
					  {
						  yyless(1);
						  return (S_ANYTHING);
					  }
					}
	YY_BREAK
case 93:
/* rule 93 can match eol */
YY_RULE_SETUP
#line 841 "pgc.l"
{
						if ( preproc_tos == 0 )
							mmerror(PARSE_ERROR, ET_FATAL, "Unmatched 'EXEC SQL ENDIF;'");
						else
							preproc_tos--;

						if ( stacked_if_value[preproc_tos].condition )
						   BEGIN(C);
						else
						   BEGIN(xskip);
					}
	YY_BREAK
case 94:
/* rule 94 can match eol */
YY_RULE_SETUP
#line 852 "pgc.l"
{
					  /* are we simulating Informix? */
					  if (INFORMIX_MODE)
					  {
						if ( preproc_tos == 0 )
							mmerror(PARSE_ERROR, ET_FATAL, "Unmatched 'EXEC SQL ENDIF;'");
						else
							preproc_tos--;

						if ( stacked_if_value[preproc_tos].condition )
						   BEGIN(C);
						else
						   BEGIN(xskip);
					  }
					  else
					  {
						  yyless(1);
						  return (S_ANYTHING);
					  }
					}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 873 "pgc.l"
{ /* ignore */ }
	YY_BREAK
case 96:
/* rule 96 can match eol */
YY_RULE_SETUP
#line 875 "pgc.l"
{
						if ( preproc_tos >= MAX_NESTED_IF-1 ) {
							mmerror(PARSE_ERROR, ET_FATAL, "Too many nested 'EXEC SQL IFDEF' conditions");
						}
						else 
						{
							struct _defines *defptr;
							unsigned int i;

							/* skip the ";" and trailing whitespace. Note that yytext contains
							   at least one non-space character plus the ";" */
							for ( i = strlen(yytext)-2;
								  i > 0 && isspace((unsigned char) yytext[i]);
								  i-- )
							{}
							yytext[i+1] = '\0';

							for ( defptr = defines; defptr != NULL &&
								  ( strcmp(yytext, defptr->old) != 0 ); defptr = defptr->next );

							preproc_tos++;
							stacked_if_value[preproc_tos].else_branch = FALSE;
							stacked_if_value[preproc_tos].condition =
							( (defptr ? ifcond : !ifcond) && stacked_if_value[preproc_tos-1].condition );
						}

						if ( stacked_if_value[preproc_tos].condition )
						   BEGIN C;
						else
						   BEGIN(xskip);
					}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 907 "pgc.l"
{
				old = mm_strdup(yytext);
				BEGIN(def);
				startlit();
			}
	YY_BREAK
case 98:
/* rule 98 can match eol */
YY_RULE_SETUP
#line 912 "pgc.l"
{
						struct _defines *ptr, *this;

						for (ptr = defines; ptr != NULL; ptr = ptr->next)
						{
							 if (strcmp(old, ptr->old) == 0)
							 {
								free(ptr->new);
								/* ptr->new = mm_strdup(scanstr(literalbuf));*/
								ptr->new = mm_strdup(literalbuf);
							 }
						}
						if (ptr == NULL)
						{
							this = (struct _defines *) mm_alloc(sizeof(struct _defines));

							/* initial definition */
							this->old = old;
							this->new = mm_strdup(literalbuf);
							this->next = defines;
							this->used = NULL;
							defines = this;
						}

						BEGIN(C);
					}
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 938 "pgc.l"
{ addlit(yytext, yyleng); }
	YY_BREAK
case 100:
/* rule 100 can match eol */
YY_RULE_SETUP
#line 940 "pgc.l"
{	parse_include(); }
	YY_BREAK
case 101:
/* rule 101 can match eol */
YY_RULE_SETUP
#line 941 "pgc.l"
{	parse_include(); }
	YY_BREAK
case 102:
/* rule 102 can match eol */
YY_RULE_SETUP
#line 942 "pgc.l"
{ parse_include(); }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(C):
case YY_STATE_EOF(SQL):
case YY_STATE_EOF(incl):
case YY_STATE_EOF(def):
case YY_STATE_EOF(def_ident):
case YY_STATE_EOF(xpre):
case YY_STATE_EOF(xcond):
case YY_STATE_EOF(xskip):
#line 944 "pgc.l"
{
				  		if (yy_buffer == NULL) {
				  		if ( preproc_tos > 0 ) 
						{
					  		preproc_tos = 0;
							mmerror(PARSE_ERROR, ET_FATAL, "Missing 'EXEC SQL ENDIF;'");
				  		}
							yyterminate();
							}
				  		else
				  		{
							struct _yy_buffer *yb = yy_buffer;
							int i;
							struct _defines *ptr;

							for (ptr = defines; ptr; ptr = ptr->next)
								if (ptr->used == yy_buffer)
							        {
									ptr->used = NULL;
							                break;
							        }
							
							if (yyin != NULL)
								fclose(yyin);

							yy_delete_buffer(YY_CURRENT_BUFFER );
							yy_switch_to_buffer(yy_buffer->buffer);

							yylineno = yy_buffer->lineno;

							/* We have to output the filename only if we change files here */
							i = strcmp(input_filename, yy_buffer->filename);

							free(input_filename);
							input_filename = yy_buffer->filename;

							yy_buffer = yy_buffer->next;
							free(yb);

							if (i != 0)
								output_line_number();
				  		}
					}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 987 "pgc.l"
ECHO;
	YY_BREAK
#line 2695 "pgc.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 446 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 446 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 445);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 987 "pgc.l"


void
lex_init(void)
{
	braces_open = 0;

	preproc_tos = 0;
	yylineno = 1;
	ifcond = TRUE;
	stacked_if_value[preproc_tos].condition = ifcond;
	stacked_if_value[preproc_tos].else_branch = FALSE;

	/* initialize literal buffer to a reasonable but expansible size */
	if (literalbuf == NULL)
	{
		literalalloc = 128;
		literalbuf = (char *) malloc(literalalloc);
	}
	startlit();

	BEGIN C;
}

static void
addlit(char *ytext, int yleng)
{
	/* enlarge buffer if needed */
	if ((literallen+yleng) >= literalalloc)
	{
		do 
			literalalloc *= 2;
		while ((literallen+yleng) >= literalalloc);
		literalbuf = (char *) realloc(literalbuf, literalalloc);
	}
	/* append new data, add trailing null */
	memcpy(literalbuf+literallen, ytext, yleng);
	literallen += yleng;
	literalbuf[literallen] = '\0';
}

static void
addlitchar(unsigned char ychar)
{
	/* enlarge buffer if needed */
        if ((literallen+1) >= literalalloc)
        {
                literalalloc *= 2;
                literalbuf = (char *) realloc(literalbuf, literalalloc);
        }
	/* append new data, add trailing null */
	literalbuf[literallen] = ychar;
	literallen += 1;
	literalbuf[literallen] = '\0';
}

static void
parse_include(void)
{
	/* got the include file name */
	struct _yy_buffer *yb;
  	struct _include_path *ip;
  	char inc_file[MAXPGPATH];
  	unsigned int i;

  	yb = mm_alloc(sizeof(struct _yy_buffer));

  	yb->buffer =	YY_CURRENT_BUFFER;
  	yb->lineno = yylineno;
  	yb->filename = input_filename;
  	yb->next = yy_buffer;

  	yy_buffer = yb;

  	/*
	 * skip the ";" if there is one and trailing whitespace. Note that
	 * yytext contains at least one non-space character plus the ";" 
	 */
  	for ( i = strlen(yytext)-2;
		i > 0 && isspace((unsigned char) yytext[i]);
		i-- )
  		{}

	if (yytext[i] == ';')
		i--;

	yytext[i+1] = '\0';
	
	yyin = NULL;

	/* If file name is enclosed in '"' remove these and look only in '.' */
	/* Informix does look into all include paths though, except filename starts with '/' */
	if ((yytext[0] == '"' && yytext[i] == '"') &&
	    ((compat != ECPG_COMPAT_INFORMIX && compat != ECPG_COMPAT_INFORMIX_SE) || yytext[1] == '/'))
	{
		yytext[i] = '\0';
		memmove(yytext, yytext+1, strlen(yytext));
	
		strncpy(inc_file, yytext, sizeof(inc_file));
		yyin = fopen(inc_file, "r");
		if (!yyin)
		{
			if (strcmp(inc_file + strlen(inc_file) - 2, ".h"))
			{
				strcat(inc_file, ".h");
				yyin = fopen(inc_file, "r");
			}
		}
		
	}
	else
	{
		if ((yytext[0] == '"' && yytext[i] == '"') || (yytext[0] == '<' && yytext[i] == '>'))
		{
			yytext[i] = '\0';
			memmove(yytext, yytext+1, strlen(yytext));
		}
		
	  	for (ip = include_paths; yyin == NULL && ip != NULL; ip = ip->next)
	  	{
			if (strlen(ip->path) + strlen(yytext) + 3 > MAXPGPATH)
			{
				fprintf(stderr, "Error: Path %s/%s is too long in line %d, skipping.\n", ip->path, yytext, yylineno);
				continue;
			}
			snprintf (inc_file, sizeof(inc_file), "%s/%s", ip->path, yytext);
			yyin = fopen(inc_file, "r");
			if (!yyin)
			{
				if (strcmp(inc_file + strlen(inc_file) - 2, ".h"))
				{
					strcat(inc_file, ".h");
					yyin = fopen( inc_file, "r" );
				}
			}
		}
	}
	if (!yyin)
	{
		snprintf(errortext, sizeof(errortext), "Cannot open include file %s in line %d\n", yytext, yylineno);
		mmerror(NO_INCLUDE_FILE, ET_FATAL, errortext);
  	}

	input_filename = mm_strdup(inc_file);
	yy_switch_to_buffer(yy_create_buffer(yyin,YY_BUF_SIZE ));
	yylineno = 1;
	output_line_number();

  	BEGIN C;
}

